@@ -18,10 +18,13 @@ from braket.schema_common import BraketSchemaBase, BraketSchemaHeader
 
 class GateModelParameters(BraketSchemaBase):
     """
-    This defines the parameters common to all the gate model devices.
+    Defines parameters common to all gate model devices.
 
     Attributes:
-        qubitCount: number of qubits for a device
+        qubitCount: Number of qubits used by the circuit.
+        disableQubitRewiring: Whether to run the circuit with the exact qubits chosen,
+            without any rewiring downstream.
+            If ``True``, no qubit rewiring is allowed; if ``False``, qubit rewiring is allowed.
 
     Examples:
         >>> import json
@@ -30,7 +33,8 @@ class GateModelParameters(BraketSchemaBase):
         ...        "name": "braket.device_schema.gate_model_parameters",
         ...        "version": "1",
         ...    },
-        ...    "qubitCount": 1
+        ...    "qubitCount": 1,
+        ...    "disableQubitRewiring": True
         ... }
         >>> GateModelParameters.parse_raw_schema(json.dumps(input_json))
     """
@@ -40,3 +44,4 @@ class GateModelParameters(BraketSchemaBase):
     )
     braketSchemaHeader: BraketSchemaHeader = Field(default=_PROGRAM_HEADER, const=_PROGRAM_HEADER)
     qubitCount: conint(strict=True, ge=0)
+    disableQubitRewiring: bool = False
