@@ -18,6 +18,8 @@ from braket.ir.jaqcd.instructions import (  # noqa: F401
     XY,
     YY,
     ZZ,
+    AmplitudeDamping,
+    BitFlip,
     CCNot,
     CNot,
     CPhaseShift,
@@ -25,9 +27,15 @@ from braket.ir.jaqcd.instructions import (  # noqa: F401
     CPhaseShift01,
     CPhaseShift10,
     CSwap,
+    Depolarizing,
+    GeneralizedAmplitudeDamping,
     H,
     I,
     ISwap,
+    Kraus,
+    PauliChannel,
+    PhaseDamping,
+    PhaseFlip,
     PhaseShift,
     PSwap,
     Rx,
@@ -38,6 +46,8 @@ from braket.ir.jaqcd.instructions import (  # noqa: F401
     Swap,
     T,
     Ti,
+    TwoQubitDephasing,
+    TwoQubitDepolarizing,
     Unitary,
     V,
     Vi,
@@ -48,6 +58,7 @@ from braket.ir.jaqcd.instructions import (  # noqa: F401
 from braket.ir.jaqcd.program_v1 import Program  # noqa: F401
 from braket.ir.jaqcd.results import (  # noqa: F401
     Amplitude,
+    DensityMatrix,
     Expectation,
     Probability,
     Sample,
